@@ -42,7 +42,7 @@ public:
     explicit MainWindow(QWidget *parent = 0);
 
 protected:
-    void closeEvent(QCloseEvent *event);
+    void closeEvent(QCloseEvent *event) Q_DECL_OVERRIDE;
 
 private slots:
     void startRandomGame();
